@@ -1,32 +1,26 @@
-#line 1
+#line 1 "inc/Class/Inspector.pm - /usr/local/share/perl/5.8.4/Class/Inspector.pm"
 package Class::Inspector;
 
 #line 40
 
-use 5.006;
-# We don't want to use strict refs anywhere in this module, since we do a
-# lot of things in here that aren't strict refs friendly.
-use strict qw{vars subs};
-use warnings;
+# Load Overhead: 236k
+
+# We don't want to use strict refs, since we do a lot of things in here
+# that arn't strict refs friendly.
+use strict     qw{vars subs};
 use File::Spec ();
 
 # Globals
-use vars qw{$VERSION $RE_IDENTIFIER $RE_CLASS $UNIX};
+use vars qw{$VERSION $RE_IDENT $RE_CLASS $UNIX};
 BEGIN {
-	$VERSION = '1.24';
-
-	# If Unicode is available, enable it so that the
-	# pattern matches below match unicode method names.
-	# We can safely ignore any failure here.
-	local $@;
-	eval "require utf8; utf8->import";
+	$VERSION = '1.13';
 
 	# Predefine some regexs
-	$RE_IDENTIFIER = qr/\A[^\W\d]\w*\z/s;
-	$RE_CLASS      = qr/\A[^\W\d]\w*(?:(?:\'|::)\w+)*\z/s;
+	$RE_IDENT = qr/\A[^\W\d]\w*\z/s;
+	$RE_CLASS = qr/\A[^\W\d]\w*(?:(?:'|::)[^\W\d]\w*)*\z/s;
 
-	# Are we on something Unix-like?
-	$UNIX  = !! ( $File::Spec::ISA[0] eq 'File::Spec::Unix'  );
+	# Are we on Unix?
+	$UNIX = !! ( $File::Spec::ISA[0] eq 'File::Spec::Unix' );
 }
 
 
@@ -36,14 +30,14 @@ BEGIN {
 #####################################################################
 # Basic Methods
 
-#line 86
+#line 80
 
 sub installed {
 	my $class = shift;
 	!! ($class->loaded_filename($_[0]) or $class->resolved_filename($_[0]));
 }
 
-#line 110
+#line 104
 
 sub loaded {
 	my $class = shift;
@@ -73,15 +67,15 @@ sub _loaded {
 	'';
 }
 
-#line 156
+#line 150
 
 sub filename {
 	my $class = shift;
 	my $name  = $class->_class(shift) or return undef;
-	File::Spec->catfile( split /(?:\'|::)/, $name ) . '.pm';
+	File::Spec->catfile( split /(?:'|::)/, $name ) . '.pm';
 }
 
-#line 182
+#line 176
 
 sub resolved_filename {
 	my $class     = shift;
@@ -99,7 +93,7 @@ sub resolved_filename {
 	'';
 }
 
-#line 211
+#line 205
 
 sub loaded_filename {
 	my $class    = shift;
@@ -114,7 +108,7 @@ sub loaded_filename {
 #####################################################################
 # Sub Related Methods
 
-#line 238
+#line 232
 
 sub functions {
 	my $class = shift;
@@ -122,13 +116,13 @@ sub functions {
 	return undef unless $class->loaded( $name );
 
 	# Get all the CODE symbol table entries
-	my @functions = sort grep { /$RE_IDENTIFIER/o }
+	my @functions = sort grep { /$RE_IDENT/o }
 		grep { defined &{"${name}::$_"} }
 		keys %{"${name}::"};
 	\@functions;
 }
 
-#line 264
+#line 258
 
 sub function_refs {
 	my $class = shift;
@@ -138,13 +132,13 @@ sub function_refs {
 	# Get all the CODE symbol table entries, but return
 	# the actual CODE refs this time.
 	my @functions = map { \&{"${name}::$_"} }
-		sort grep { /$RE_IDENTIFIER/o }
+		sort grep { /$RE_IDENT/o }
 		grep { defined &{"${name}::$_"} }
 		keys %{"${name}::"};
 	\@functions;
 }
 
-#line 293
+#line 287
 
 sub function_exists {
 	my $class    = shift;
@@ -158,7 +152,7 @@ sub function_exists {
 	defined &{"${name}::$function"};
 }
 
-#line 372
+#line 366
 
 sub methods {
 	my $class     = shift;
@@ -215,7 +209,7 @@ sub methods {
 	my %methods = ();
 	foreach my $namespace ( @path ) {
 		my @functions = grep { ! $methods{$_} }
-			grep { /$RE_IDENTIFIER/o }
+			grep { /$RE_IDENT/o }
 			grep { defined &{"${namespace}::$_"} } 
 			keys %{"${namespace}::"};
 		foreach ( @functions ) {
@@ -244,7 +238,7 @@ sub methods {
 #####################################################################
 # Search Methods
 
-#line 473
+#line 467
 
 sub subclasses {
 	my $class = shift;
@@ -262,7 +256,6 @@ sub subclasses {
 			# over that (bizarre) class. That would at limit
 			# problems with finding subclasses to only the
 			# modules that have broken ->isa implementation.
-			local $@;
 			eval {
 				if ( $c->isa($name) ) {
 					# Add to the found list, but don't add the class itself
@@ -286,7 +279,7 @@ sub _subnames {
 		grep {
 			substr($_, -2, 2, '') eq '::'
 			and
-			/$RE_IDENTIFIER/o
+			/$RE_IDENT/o
 		}
 		keys %{"${name}::"};
 }
@@ -357,25 +350,23 @@ sub _class {
 sub _inc_filename {
 	my $class = shift;
 	my $name  = $class->_class(shift) or return undef;
-	join( '/', split /(?:\'|::)/, $name ) . '.pm';
+	join( '/', split /(?:'|::)/, $name ) . '.pm';
 }
 
 # Convert INC-specific file name to local file name
 sub _inc_to_local {
-	# Shortcut in the Unix case
-	return $_[1] if $UNIX;
+	my $class = shift;
 
-	# On other places, we have to deal with an unusual path that might look
-	# like C:/foo/bar.pm which doesn't fit ANY normal pattern.
-	# Putting it through splitpath/dir and back again seems to normalise
-	# it to a reasonable amount.
-	my $class              = shift;
-	my $inc_name           = shift or return undef;
-	my ($vol, $dir, $file) = File::Spec->splitpath( $inc_name );
-	$dir = File::Spec->catdir( File::Spec->splitdir( $dir || "" ) );
+	# Shortcut in the Unix case
+	return $_[0] if $UNIX;
+
+	# Get the INC filename and convert
+	my $inc_name = shift or return undef;
+	my ($vol, $dir, $file) = File::Spec::Unix->splitpath( $inc_name );
+	$dir = File::Spec->catdir( File::Spec::Unix->splitdir( $dir || "" ) );
 	File::Spec->catpath( $vol, $dir, $file || "" );
 }
 
 1;
 
-#line 635
+#line 630
