@@ -1,14 +1,10 @@
-#line 1
+#line 1 "inc/Hook/LexWrap.pm - /usr/local/share/perl/5.8.4/Hook/LexWrap.pm"
 package Hook::LexWrap;
+our $VERSION = '0.20';
 use 5.006;
-use strict;
-use warnings;
-our $VERSION = '0.22';
 use Carp;
 
-{
-no warnings 'redefine';
-*CORE::GLOBAL::caller = sub (;$) {
+*CORE::GLOBAL::caller = sub {
 	my ($height) = ($_[0]||0);
 	my $i=1;
 	my $name_cache;
@@ -20,28 +16,23 @@ no warnings 'redefine';
 		return wantarray ? @_ ? @caller : @caller[0..2] : $caller[0];
 	}
 };
-}
 
-sub import { no strict 'refs'; *{caller()."::wrap"} = \&wrap }
+sub import { *{caller()."::wrap"} = \&wrap }
 
-sub wrap (*@) {  ## no critic Prototypes
+sub wrap (*@) {
 	my ($typeglob, %wrapper) = @_;
 	$typeglob = (ref $typeglob || $typeglob =~ /::/)
 		? $typeglob
 		: caller()."::$typeglob";
-	my $original;
-	{
-	        no strict 'refs';
-	        $original = ref $typeglob eq 'CODE' && $typeglob
+	my $original = ref $typeglob eq 'CODE' && $typeglob
 		     || *$typeglob{CODE}
 		     || croak "Can't wrap non-existent subroutine ", $typeglob;
-	}
 	croak "'$_' value is not a subroutine reference"
 		foreach grep {$wrapper{$_} && ref $wrapper{$_} ne 'CODE'}
 			qw(pre post);
 	no warnings 'redefine';
 	my ($caller, $unwrap) = *CORE::GLOBAL::caller{CODE};
-	my $imposter = sub {
+	$imposter = sub {
 		if ($unwrap) { goto &$original }
 		my ($return, $prereturn);
 		if (wantarray) {
@@ -78,10 +69,7 @@ sub wrap (*@) {  ## no critic Prototypes
 	ref $typeglob eq 'CODE' and return defined wantarray
 		? $imposter
 		: carp "Uselessly wrapped subroutine reference in void context";
-	{
-	        no strict 'refs';
-	        *{$typeglob} = $imposter;
-	}
+	*{$typeglob} = $imposter;
 	return unless defined wantarray;
 	return bless sub{ $unwrap=1 }, 'Hook::LexWrap::Cleanup';
 }
