@@ -1,20 +1,18 @@
-#line 1
+#line 1 "inc/Test/ClassAPI.pm - /usr/local/share/perl/5.8.4/Test/ClassAPI.pm"
 package Test::ClassAPI;
 
 # Allows us to test class APIs in a simplified manner.
 # Implemented as a wrapper around Test::More, Class::Inspector and Config::Tiny.
 
-use 5.006;
 use strict;
-use File::Spec       0.83 ();
-use Test::More       0.47 ();
-use Config::Tiny     2.00 ();
-use Class::Inspector 1.12 ();
-use Params::Util     1.00 '_INSTANCE';
+use UNIVERSAL 'isa';
+use Test::More       ();
+use Config::Tiny     ();
+use Class::Inspector ();
 
 use vars qw{$VERSION $CONFIG $SCHEDULE $EXECUTED %IGNORE *DATA};
 BEGIN {
-	$VERSION = '1.06';
+	$VERSION = '1.02';
 
 	# Config starts empty
 	$CONFIG   = undef;
@@ -59,7 +57,7 @@ sub init {
 	my $class = shift;
 
 	# Use the script's DATA handle or one passed
-	*DATA = ref($_[0]) eq 'GLOB' ? shift : *main::DATA;
+	*DATA = isa( $_[0], 'GLOB' ) ? shift : *main::DATA;
  
 	# Read in all the data, and create the config object
 	local $/ = undef;
@@ -130,26 +128,17 @@ sub execute {
 		my %known_methods = ();
 		my @implements = ();
 		foreach my $parent ( @path ) {
-			foreach my $test ( sort keys %{$CONFIG->{$parent}} ) {
+			foreach my $test ( keys %{$CONFIG->{$parent}} ) {
 				my $type = $CONFIG->{$parent}->{$test};
-
-				# Does the class have a named method
 				if ( $type eq 'method' ) {
+					# Does the class have a method
 					$known_methods{$test}++;
 					Test::More::can_ok( $class, $test );
-					next;
-				}
-
-				# Does the class inherit from a named parent
-				if ( $type eq 'isa' ) {
-					Test::More::ok( $class->isa($test), "$class isa $test" );
-					next;
-				}
-
-				unless ( $type eq 'implements' ) {
-					print "# Warning: Unknown test type '$type'";
-					next;
+				} elsif ( $type eq 'isa' ) {
+					# Does the class inherit from a parent
+					Test::More::ok( isa( $class, $test ), "$class isa $test" );
 				}
+				next unless $type eq 'implements';
 				
 				# When we 'implement' a class or interface,
 				# we need to check the 'method' tests within
@@ -219,4 +208,4 @@ sub execute {
 
 __END__
 
-#line 351
+#line 339
